@@ -1,7 +1,7 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qt Creator.
 **
@@ -9,22 +9,17 @@
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company.  For licensing terms and
-** conditions see http://www.qt.io/terms-conditions.  For further information
-** use the contact form at http://www.qt.io/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, The Qt Company gives you certain additional
-** rights.  These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ****************************************************************************/
 
@@ -36,6 +31,8 @@
 
 #include <projectexplorer/session.h>
 
+#include <algorithm>
+
 using namespace CppEditor::Internal;
 
 static bool projectPartLessThan(const CppTools::ProjectPart::Ptr &projectPart1,
@@ -63,14 +60,14 @@ CppPreProcessorDialog::CppPreProcessorDialog(QWidget *parent, const QString &fil
     int currentIndex = 0;
 
     QList<CppTools::ProjectPart::Ptr> sortedProjectParts(projectParts);
-    qStableSort(sortedProjectParts.begin(), sortedProjectParts.end(), projectPartLessThan);
+    std::stable_sort(sortedProjectParts.begin(), sortedProjectParts.end(), projectPartLessThan);
 
     foreach (CppTools::ProjectPart::Ptr projectPart, sortedProjectParts) {
         m_ui->projectComboBox->addItem(projectPart->displayName);
         ProjectPartAddition addition;
         addition.projectPart = projectPart;
         addition.additionalDirectives = ProjectExplorer::SessionManager::value(
-                    projectPart->projectFile + QLatin1Char(',') +  m_filePath).toString();
+                    projectPart->id() + QLatin1Char(',') +  m_filePath).toString();
         if (projectPart->id() == projectPartIdToUse)
             currentIndex = m_ui->projectComboBox->count() - 1;
         m_partAdditions << addition;
@@ -80,8 +77,10 @@ CppPreProcessorDialog::CppPreProcessorDialog(QWidget *parent, const QString &fil
     m_ui->projectComboBox->setCurrentIndex(currentIndex);
     m_ui->editWidget->setPlainText(m_partAdditions.value(currentIndex).additionalDirectives);
 
-    connect(m_ui->projectComboBox, SIGNAL(currentIndexChanged(int)), SLOT(projectChanged(int)));
-    connect(m_ui->editWidget, SIGNAL(textChanged()), SLOT(textChanged()));
+    connect(m_ui->projectComboBox,
+            static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
+            this, &CppPreProcessorDialog::projectChanged);
+    connect(m_ui->editWidget, &QPlainTextEdit::textChanged, this, &CppPreProcessorDialog::textChanged);
 }
 
 CppPreProcessorDialog::~CppPreProcessorDialog()
@@ -96,16 +95,16 @@ int CppPreProcessorDialog::exec()
 
     ProjectExplorer::SessionManager::setValue(
                 QLatin1String(Constants::CPP_PREPROCESSOR_PROJECT_PREFIX) + m_filePath,
-                m_partAdditions[m_ui->projectComboBox->currentIndex()].projectPart->projectFile);
+                m_partAdditions[m_ui->projectComboBox->currentIndex()].projectPart->id());
 
     foreach (ProjectPartAddition partAddition, m_partAdditions) {
         const QString &previousDirectives = ProjectExplorer::SessionManager::value(
-                    partAddition.projectPart->projectFile
+                    partAddition.projectPart->id()
                     + QLatin1Char(',')
                     + m_filePath).toString();
         if (previousDirectives != partAddition.additionalDirectives) {
             ProjectExplorer::SessionManager::setValue(
-                        partAddition.projectPart->projectFile + QLatin1Char(',') +  m_filePath,
+                        partAddition.projectPart->id() + QLatin1Char(',') +  m_filePath,
                         partAddition.additionalDirectives);
         }
     }
